@@ -8,7 +8,7 @@ use Readonly;
 use Moose; use MooseX::StrictConstructor;
 use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = 'v0.55.3'; # VERSION
+our $VERSION = 'v0.55.4'; # VERSION
 
 extends 'Throwable::Error';
 
@@ -31,7 +31,7 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version v0.55.3
+version v0.55.4
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ L<CloudFlare::Client|CloudFlare::Client>
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc CloudFlare::Client::Exception::Upstream
+  perldoc CloudFlare::Client
 
 =head2 Websites
 
@@ -152,7 +152,7 @@ Peter Roberts <me+dev@peter-r.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Peter Roberts.
+This software is Copyright (c) 2016 by Peter Roberts.
 
 This is free software, licensed under:
 
